# aws-arn
A complete list of all AWS ARNs

Isn't anyoning trying to guess the ARN for a specific AWS resource? This is a complete list of all AWS ARNs. The list is sorted alphabetically by service and resource.  This is the only complete list of AWS ARNs available anywhere.

> :warning: **Work in progress**: This is a work in progress.  Not all services and resources are included yet.  Please open an issue or pull request if you find any errors or omissions.

- Total number of services:  151
- Total number of resources:  463

# Use it as a module

```
import aws_arn

arn = aws_arn.generate_arn('i-1234568901', 'ec2', 'instance', 'us-east-1', '012345789012', 'aws')

print (arn)

arn:aws:ec2:us-east-1:012345789012:instance/i-1234568901

```

# Use it as CLI

```
./main.py --generate-arn --id test --service ec2 --sub-service instance --region us-east-1 --account 012345789012 --partition aws

arn:aws:ec2:us-east-1:012345789012:instance/test
```

## Full List of ARNs

| Service | ARN Format |
| --- | --- |
| acm | certificate: `arn:${Partition}:acm:${Region}:${Account}:certificate/${CertificateId}`<br> |
| acm-pca | certificate_authority: `arn:${Partition}:acm-pca:${Region}:${Account}:certificate-authority/${CertificateAuthorityId}`<br> |
| alexaforbusiness | skill: `arn:${Partition}:aplb:${Region}:${Account}:skill/${SkillId}`<br> |
| apigateway | api: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}`<br>api_key: `arn:${Partition}:apigateway:${Region}::/apikeys/${ApiKeyId}`<br>authorizer: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/authorizers/${AuthorizerId}`<br>base_path_mapping: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/basepathmappings/${BasePathMappingId}`<br>client_certificate: `arn:${Partition}:apigateway:${Region}::/clientcertificates/${ClientCertificateId}`<br>deployment: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/deployments/${DeploymentId}`<br>documentation_part: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/documentation/parts/${DocumentationPartId}`<br>documentation_version: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/documentation/versions/${DocumentationVersion}`<br>domain_name: `arn:${Partition}:apigateway:${Region}::/domainnames/${DomainName}`<br>gateway_response: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/gatewayresponses/${GatewayResponseId}`<br>integration: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/resources/${ResourceId}/methods/${HttpMethod}/integrations/${IntegrationId}`<br>method: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/resources/${ResourceId}/methods/${HttpMethod}`<br>model: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/models/${ModelName}`<br>request_validator: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/requestvalidators/${RequestValidatorId}`<br>resource: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/resources/${ResourceId}`<br>rest_api: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}`<br>stage: `arn:${Partition}:apigateway:${Region}::/restapis/${ApiId}/stages/${StageName}`<br>usage_plan: `arn:${Partition}:apigateway:${Region}::/usageplans/${UsagePlanId}`<br>usage_plan_key: `arn:${Partition}:apigateway:${Region}::/usageplans/${UsagePlanId}/keys/${KeyId}`<br>vpc_link: `arn:${Partition}:apigateway:${Region}::/vpclinks/${VpcLinkId}`<br> |
| appflow | connector_profile: `arn:${Partition}:appflow:${Region}:${Account}:connectorprofile/${ConnectorProfileName}`<br>flow: `arn:${Partition}:appflow:${Region}:${Account}:flow/${FlowName}`<br> |
| appstream | directory_config: `arn:${Partition}:appstream:${Region}:${Account}:directoryconfig/${DirectoryConfigName}`<br>fleet: `arn:${Partition}:appstream:${Region}:${Account}:fleet/${FleetName}`<br>image: `arn:${Partition}:appstream:${Region}:${Account}:image/${ImageName}`<br>image_builder: `arn:${Partition}:appstream:${Region}:${Account}:imagebuilder/${ImageBuilderName}`<br>stack: `arn:${Partition}:appstream:${Region}:${Account}:stack/${StackName}`<br> |
| athena | workgroup: `arn:${Partition}:athena:${Region}:${Account}:workgroup/${WorkGroupName}`<br> |
| augmentedairuntime | human_loop: `arn:${Partition}:sagemaker:${Region}:${Account}:human-loop/${HumanLoopName}`<br> |
| autoscaling | auto_scaling_group: `arn:${Partition}:autoscaling:${Region}:${Account}:autoScalingGroup:${AutoScalingGroupName}`<br>launch_configuration: `arn:${Partition}:autoscaling:${Region}:${Account}:launchConfiguration:${LaunchConfigurationName}`<br> |
| batch | compute_environment: `arn:${Partition}:batch:${Region}:${Account}:compute-environment/${ComputeEnvironmentName}`<br>job_definition: `arn:${Partition}:batch:${Region}:${Account}:job-definition/${JobDefinitionName}:${JobDefinitionVersion}`<br>job_queue: `arn:${Partition}:batch:${Region}:${Account}:job-queue/${JobQueueName}`<br> |
| budgets | budget: `arn:${Partition}:budgets:${Region}:${Account}:budget/${BudgetName}`<br> |
| cloud9 | environment: `arn:${Partition}:cloud9:${Region}:${Account}:environment:${EnvironmentId}`<br> |
| cloudformation | change_set: `arn:${Partition}:cloudformation:${Region}:${Account}:changeSet/${ChangeSetId}`<br>stack: `arn:${Partition}:cloudformation:${Region}:${Account}:stack/${StackName}/${StackId}`<br> |
| cloudfront | distribution: `arn:${Partition}:cloudfront::${Account}:distribution/${DistributionId}`<br>field_level_encryption_config: `arn:${Partition}:cloudfront::${Account}:field-level-encryption-config/${FieldLevelEncryptionConfigId}`<br>field_level_encryption_profile: `arn:${Partition}:cloudfront::${Account}:field-level-encryption-profile/${FieldLevelEncryptionProfileId}`<br>realtime_log_config: `arn:${Partition}:cloudfront::${Account}:realtime-log-config/${RealtimeLogConfigId}`<br> |
| cloudhsmv2 | cluster: `arn:${Partition}:cloudhsmv2:${Region}:${Account}:cluster/${ClusterId}`<br>backup: `arn:${Partition}:cloudhsmv2:${Region}:${Account}:backup/${BackupId}`<br>hsm: `arn:${Partition}:cloudhsmv2:${Region}:${Account}:cluster/${ClusterId}/hsm/${HsmId}`<br> |
| cloudtrail | trail: `arn:${Partition}:cloudtrail:${Region}:${Account}:trail/${TrailName}`<br> |
| cloudwatch | alarm: `arn:${Partition}:cloudwatch:${Region}:${Account}:alarm:${AlarmName}`<br>dashboard: `arn:${Partition}:cloudwatch::${Account}:dashboard/${DashboardName}`<br> |
| codeartifact | domain: `arn:${Partition}:codeartifact:${Region}:${Account}:domain/${DomainName}`<br>package: `arn:${Partition}:codeartifact:${Region}:${Account}:repository/${DomainName}/${RepositoryName}/package/${PackageFormat}/${PackageName}@${PackageVersion}`<br>repository: `arn:${Partition}:codeartifact:${Region}:${Account}:repository/${DomainName}/${RepositoryName}`<br> |
| codebuild | project: `arn:${Partition}:codebuild:${Region}:${Account}:project/${ProjectName}`<br> |
| codecommit | repository: `arn:${Partition}:codecommit:${Region}:${Account}:${RepositoryName}`<br> |
| codedeploy | application: `arn:${Partition}:codedeploy:${Region}:${Account}:application:${ApplicationName}`<br>deployment_config: `arn:${Partition}:codedeploy:${Region}:${Account}:deploymentconfig:${DeploymentConfigName}`<br>deployment_group: `arn:${Partition}:codedeploy:${Region}:${Account}:deploymentgroup:${ApplicationName}/${DeploymentGroupName}`<br> |
| codepipeline | pipeline: `arn:${Partition}:codepipeline:${Region}:${Account}:${PipelineName}`<br> |
| codestar-connections | connection: `arn:${Partition}:codestar-connections:${Region}:${Account}:connection/${ConnectionName}`<br> |
| codestar-notifications | rule: `arn:${Partition}:codestar-notifications:${Region}:${Account}:notificationrule/${NotificationRuleId}`<br> |
| cognito-idp | identity_provider: `arn:${Partition}:cognito-idp:${Region}:${Account}:userpool/${UserPoolId}:identityprovider/${ProviderName}`<br>resource_server: `arn:${Partition}:cognito-idp:${Region}:${Account}:userpool/${UserPoolId}/resource-server/${ResourceServerId}`<br>user_pool: `arn:${Partition}:cognito-idp:${Region}:${Account}:userpool/${UserPoolId}`<br> |
| comprehend | document_classifier: `arn:${Partition}:comprehend:${Region}:${Account}:document-classifier/${DocumentClassifierName}`<br>entity_recognizer: `arn:${Partition}:comprehend:${Region}:${Account}:entity-recognizer/${EntityRecognizerName}`<br>key_phrases_detection_job: `arn:${Partition}:comprehend:${Region}:${Account}:key-phrases-detection-job/${KeyPhrasesDetectionJobName}`<br>sentiment_detection_job: `arn:${Partition}:comprehend:${Region}:${Account}:sentiment-detection-job/${SentimentDetectionJobName}`<br>topic_detection_job: `arn:${Partition}:comprehend:${Region}:${Account}:topic-detection-job/${TopicDetectionJobName}`<br> |
| compute-optimizer | recommendation_export_job: `arn:${Partition}:compute-optimizer:${Region}:${Account}:recommendation-export-job/${ExportJobId}`<br> |
| config | aggregator: `arn:${Partition}:config:${Region}:${Account}:config-aggregator/${ConfigAggregatorName}`<br>conformance_pack: `arn:${Partition}:config:${Region}:${Account}:conformance-pack/${ConformancePackName}`<br>config_rule: `arn:${Partition}:config:${Region}:${Account}:config-rule/${ConfigRuleName}`<br>organization_config_rule: `arn:${Partition}:config:${Region}:${Account}:organization-config-rule/${OrganizationConfigRuleName}`<br>remediation_configuration: `arn:${Partition}:config:${Region}:${Account}:remediation-configuration/${RemediationConfigurationName}`<br> |
| cur | report_definition: `arn:${Partition}:cur:${ReportName}-${YYYYMM}-${AdditionalArtifact}-${Region}-${Account}`<br> |
| dataexchange | asset: `arn:${Partition}:dataexchange:${Region}:${Account}:asset/${AssetId}`<br>data_set: `arn:${Partition}:dataexchange:${Region}:${Account}:data-sets/${DataSetId}`<br>job: `arn:${Partition}:dataexchange:${Region}:${Account}:job/${JobId}`<br>revision: `arn:${Partition}:dataexchange:${Region}:${Account}:revision/${RevisionId}`<br> |
| datapipeline | pipeline: `arn:${Partition}:datapipeline:${Region}:${Account}:${PipelineId}`<br> |
| dax | cluster: `arn:${Partition}:dax:${Region}:${Account}:cluster:${ClusterName}`<br> |
| devicefarm | project: `arn:${Partition}:devicefarm:${Region}:${Account}:project:${ProjectArnSuffix}`<br>device_instance: `arn:${Partition}:devicefarm:${Region}:${Account}:device-instance:${DeviceInstanceArnSuffix}`<br>device_pool: `arn:${Partition}:devicefarm:${Region}:${Account}:devicepool:${DevicePoolArnSuffix}`<br>run: `arn:${Partition}:devicefarm:${Region}:${Account}:run:${RunArnSuffix}`<br>job: `arn:${Partition}:devicefarm:${Region}:${Account}:job:${JobArnSuffix}`<br>suite: `arn:${Partition}:devicefarm:${Region}:${Account}:suite:${SuiteArnSuffix}`<br>test: `arn:${Partition}:devicefarm:${Region}:${Account}:test:${TestArnSuffix}`<br> |
| directconnect | connection: `arn:${Partition}:directconnect:${Region}:${Account}:dxcon:${ConnectionId}`<br>link_aggregation_group: `arn:${Partition}:directconnect:${Region}:${Account}:linkaggregations:${LagId}`<br>private_virtual_interface: `arn:${Partition}:directconnect:${Region}:${Account}:dxvif:${VirtualInterfaceId}`<br>public_virtual_interface: `arn:${Partition}:directconnect:${Region}:${Account}:dxvif:${VirtualInterfaceId}`<br>transit_virtual_interface: `arn:${Partition}:directconnect:${Region}:${Account}:dxvif:${VirtualInterfaceId}`<br> |
| dynamodb | table: `arn:${Partition}:dynamodb:${Region}:${Account}:table/${TableName}`<br> |
| ec2 | customer_gateway: `arn:${Partition}:ec2:${Region}:${Account}:customer-gateway/${CustomerGatewayId}`<br>dedicated_host: `arn:${Partition}:ec2:${Region}:${Account}:host/${DedicatedHostId}`<br>dhcp_options: `arn:${Partition}:ec2:${Region}:${Account}:dhcp-options/${DhcpOptionsId}`<br>egress_only_internet_gateway: `arn:${Partition}:ec2:${Region}:${Account}:egress-only-internet-gateway/${EgressOnlyInternetGatewayId}`<br>elastic_gpu: `arn:${Partition}:ec2:${Region}:${Account}:elastic-gpu/${ElasticGpuId}`<br>elastic_inference_accelerator: `arn:${Partition}:elastic-inference:${Region}:${Account}:accelerator/${AcceleratorId}`<br>flow_log: `arn:${Partition}:ec2:${Region}:${Account}:flow-log/${FlowLogId}`<br>image: `arn:${Partition}:ec2:${Region}:${Account}:image/${ImageId}`<br>instance: `arn:${Partition}:ec2:${Region}:${Account}:instance/${InstanceId}`<br>internet_gateway: `arn:${Partition}:ec2:${Region}:${Account}:internet-gateway/${InternetGatewayId}`<br>key_pair: `arn:${Partition}:ec2:${Region}:${Account}:key-pair/${KeyName}`<br>launch_template: `arn:${Partition}:ec2:${Region}:${Account}:launch-template/${LaunchTemplateId}`<br>nat_gateway: `arn:${Partition}:ec2:${Region}:${Account}:natgateway/${NatGatewayId}`<br>network_acl: `arn:${Partition}:ec2:${Region}:${Account}:network-acl/${NetworkAclId}`<br>network_interface: `arn:${Partition}:ec2:${Region}:${Account}:network-interface/${NetworkInterfaceId}`<br>placement_group: `arn:${Partition}:ec2:${Region}:${Account}:placement-group/${PlacementGroupName}`<br>reserved_instances: `arn:${Partition}:ec2:${Region}:${Account}:reserved-instances/${ReservedInstancesId}`<br>route_table: `arn:${Partition}:ec2:${Region}:${Account}:route-table/${RouteTableId}`<br>security_group: `arn:${Partition}:ec2:${Region}:${Account}:security-group/${SecurityGroupId}`<br>snapshot: `arn:${Partition}:ec2:${Region}:${Account}:snapshot/${SnapshotId}`<br>spot_fleet_request: `arn:${Partition}:ec2:${Region}:${Account}:spot-fleet-request/${SpotFleetRequestId}`<br>spot_instance_request: `arn:${Partition}:ec2:${Region}:${Account}:spot-instances-request/${SpotInstanceRequestId}`<br>subnet: `arn:${Partition}:ec2:${Region}:${Account}:subnet/${SubnetId}`<br>traffic_mirror_filter: `arn:${Partition}:ec2:${Region}:${Account}:traffic-mirror-filter/${TrafficMirrorFilterId}`<br>traffic_mirror_session: `arn:${Partition}:ec2:${Region}:${Account}:traffic-mirror-session/${TrafficMirrorSessionId}`<br>traffic_mirror_target: `arn:${Partition}:ec2:${Region}:${Account}:traffic-mirror-target/${TrafficMirrorTargetId}`<br>transit_gateway: `arn:${Partition}:ec2:${Region}:${Account}:transit-gateway/${TransitGatewayId}`<br>transit_gateway_attachment: `arn:${Partition}:ec2:${Region}:${Account}:transit-gateway-attachment/${TransitGatewayAttachmentId}`<br>transit_gateway_multicast_domain: `arn:${Partition}:ec2:${Region}:${Account}:transit-gateway-multicast-domain/${TransitGatewayMulticastDomainId}`<br>transit_gateway_route_table: `arn:${Partition}:ec2:${Region}:${Account}:transit-gateway-route-table/${TransitGatewayRouteTableId}`<br>volume: `arn:${Partition}:ec2:${Region}:${Account}:volume/${VolumeId}`<br>vpc: `arn:${Partition}:ec2:${Region}:${Account}:vpc/${VpcId}`<br>vpc_endpoint: `arn:${Partition}:ec2:${Region}:${Account}:vpc-endpoint/${VpcEndpointId}`<br>vpc_endpoint_service: `arn:${Partition}:ec2:${Region}:${Account}:vpc-endpoint-service/${VpcEndpointServiceId}`<br>vpc_peering_connection: `arn:${Partition}:ec2:${Region}:${Account}:vpc-peering-connection/${VpcPeeringConnectionId}`<br>vpn_connection: `arn:${Partition}:ec2:${Region}:${Account}:vpn-connection/${VpnConnectionId}`<br>vpn_gateway: `arn:${Partition}:ec2:${Region}:${Account}:vpn-gateway/${VpnGatewayId}`<br> |
| ec2-instance-connect | connect: `arn:${Partition}:ec2-instance-connect:${Region}:${Account}:connect/${InstanceId}`<br> |
| ecr | repository: `arn:${Partition}:ecr:${Region}:${Account}:repository/${RepositoryName}`<br> |
| ecs | cluster: `arn:${Partition}:ecs:${Region}:${Account}:cluster/${ClusterName}`<br>task_definition: `arn:${Partition}:ecs:${Region}:${Account}:task-definition/${TaskDefinitionFamily}:${TaskDefinitionRevision}`<br>task: `arn:${Partition}:ecs:${Region}:${Account}:task/${TaskId}`<br>service: `arn:${Partition}:ecs:${Region}:${Account}:service/${ClusterName}/${ServiceName}`<br>container_instance: `arn:${Partition}:ecs:${Region}:${Account}:container-instance/${ContainerInstanceId}`<br> |
| efs | file_system: `arn:${Partition}:elasticfilesystem:${Region}:${Account}:file-system/${FileSystemId}`<br> |
| eks | cluster: `arn:${Partition}:eks:${Region}:${Account}:cluster/${ClusterName}`<br> |
| elastic-inference | accelerator_type: `arn:${Partition}:elastic-inference:${Region}:${Account}:accelerator-type/${AcceleratorTypeName}`<br> |
| elasticache | cache_cluster: `arn:${Partition}:elasticache:${Region}:${Account}:cluster:${CacheClusterId}`<br>cache_parameter_group: `arn:${Partition}:elasticache:${Region}:${Account}:parameter-group:${CacheParameterGroupName}`<br>cache_security_group: `arn:${Partition}:elasticache:${Region}:${Account}:security-group:${CacheSecurityGroupName}`<br>cache_subnet_group: `arn:${Partition}:elasticache:${Region}:${Account}:subnet-group:${CacheSubnetGroupName}`<br>global_replication_group: `arn:${Partition}:elasticache:${Region}:${Account}:global-replication-group:${GlobalReplicationGroupId}`<br>replication_group: `arn:${Partition}:elasticache:${Region}:${Account}:cluster:${ReplicationGroupId}`<br>user_group: `arn:${Partition}:elasticache:${Region}:${Account}:user-group:${UserGroupId}`<br> |
| elasticbeanstalk | application: `arn:${Partition}:elasticbeanstalk:${Region}:${Account}:application/${ApplicationName}`<br>application_version: `arn:${Partition}:elasticbeanstalk:${Region}:${Account}:applicationversion/${ApplicationName}/${ApplicationVersionName}`<br>environment: `arn:${Partition}:elasticbeanstalk:${Region}:${Account}:environment/${EnvironmentId}`<br> |
| elasticfilesystem | file_system: `arn:${Partition}:elasticfilesystem:${Region}:${Account}:file-system/${FileSystemId}`<br>mount_target: `arn:${Partition}:elasticfilesystem:${Region}:${Account}:mount-target/${MountTargetId}`<br> |
| elasticloadbalancing | load_balancer: `arn:${Partition}:elasticloadbalancing:${Region}:${Account}:loadbalancer/${LoadBalancerName}`<br>target_group: `arn:${Partition}:elasticloadbalancing:${Region}:${Account}:targetgroup/${TargetGroupName}/${TargetGroupID}`<br>listener: `arn:${Partition}:elasticloadbalancing:${Region}:${Account}:listener/${LoadBalancerName}/${ListenerId}`<br>listener_rule: `arn:${Partition}:elasticloadbalancing:${Region}:${Account}:listener-rule/${LoadBalancerName}/${ListenerRuleId}`<br> |
| elasticmapreduce | cluster: `arn:${Partition}:elasticmapreduce:${Region}:${Account}:cluster/${ClusterId}`<br>security_configuration: `arn:${Partition}:elasticmapreduce:${Region}:${Account}:security-configuration/${SecurityConfigurationName}`<br>step: `arn:${Partition}:elasticmapreduce:${Region}:${Account}:cluster/${ClusterId}/step/${StepId}`<br> |
| elastictranscoder | pipeline: `arn:${Partition}:elastictranscoder:${Region}:${Account}:pipeline/${PipelineId}`<br>preset: `arn:${Partition}:elastictranscoder:${Region}:${Account}:preset/${PresetId}`<br> |
| es | domain: `arn:${Partition}:es:${Region}:${Account}:domain/${DomainName}`<br> |
| events | archive: `arn:${Partition}:events:${Region}:${Account}:archive/${ArchiveName}`<br>bus: `arn:${Partition}:events:${Region}:${Account}:event-bus/${EventBusName}`<br>rule: `arn:${Partition}:events:${Region}:${Account}:rule/${RuleName}`<br> |
| firehose | delivery_stream: `arn:${Partition}:firehose:${Region}:${Account}:deliverystream/${DeliveryStreamName}`<br> |
| fms | policy: `arn:${Partition}:fms:${Region}:${Account}:policy/${PolicyName}`<br> |
| fsx | backup: `arn:${Partition}:fsx:${Region}:${Account}:backup/${BackupId}`<br>file_system: `arn:${Partition}:fsx:${Region}:${Account}:file-system/${FileSystemId}`<br> |
| gamelift | alias: `arn:${Partition}:gamelift:${Region}:${Account}:alias/${AliasId}`<br>build: `arn:${Partition}:gamelift:${Region}:${Account}:build/${BuildId}`<br>fleet: `arn:${Partition}:gamelift:${Region}:${Account}:fleet/${FleetId}`<br> |
| glacier | vault: `arn:${Partition}:glacier:${Region}:${Account}:vaults/${VaultName}`<br> |
| globalaccelerator | accelerator: `arn:${Partition}:globalaccelerator::${Account}:accelerator/${AcceleratorId}`<br>listener: `arn:${Partition}:globalaccelerator::${Account}:listener/${AcceleratorId}/${ListenerId}`<br>endpoint_group: `arn:${Partition}:globalaccelerator::${Account}:endpoint-group/${EndpointGroupId}`<br> |
| glue | catalog: `arn:${Partition}:glue:${Region}:${Account}:catalog`<br>crawler: `arn:${Partition}:glue:${Region}:${Account}:crawler:${CrawlerName}`<br>database: `arn:${Partition}:glue:${Region}:${Account}:database/${DatabaseName}`<br>dev_endpoint: `arn:${Partition}:glue:${Region}:${Account}:devEndpoint/${DevEndpointName}`<br>job: `arn:${Partition}:glue:${Region}:${Account}:job/${JobName}`<br>partition: `arn:${Partition}:glue:${Region}:${Account}:table/${DatabaseName}/${TableName}/partition/${PartitionValues}`<br>trigger: `arn:${Partition}:glue:${Region}:${Account}:trigger/${TriggerName}`<br>workflow: `arn:${Partition}:glue:${Region}:${Account}:workflow/${WorkflowName}`<br> |
| greengrass | group: `arn:${Partition}:greengrass:${Region}:${Account}:/greengrass/groups/${GroupId}`<br> |
| guardduty | detector: `arn:${Partition}:guardduty:${Region}:${Account}:detector/${DetectorId}`<br>filter: `arn:${Partition}:guardduty:${Region}:${Account}:detector/${DetectorId}/filter/${FilterName}`<br>ipset: `arn:${Partition}:guardduty:${Region}:${Account}:detector/${DetectorId}/ipset/${IpSetId}`<br>member: `arn:${Partition}:guardduty:${Region}:${Account}:detector/${DetectorId}/member/${MemberId}`<br>threatintelset: `arn:${Partition}:guardduty:${Region}:${Account}:detector/${DetectorId}/threatintelset/${ThreatIntelSetId}`<br> |
| health | event: `arn:${Partition}:health:${Region}:${Account}:event/${EventArn}`<br>health_check: `arn:${Partition}:health:${Region}:${Account}:healthcheck/${HealthCheckId}`<br>organization_event_detail: `arn:${Partition}:health:${Region}:${Account}:event-organization/${EventTypeCode}/${Service}/${EventTypeVersion}/${EventId}`<br>service: `arn:${Partition}:health:${Region}:${Account}:service/${Service}`<br> |
| iam | access_key: `arn:${Partition}:iam::${Account}:accesskey/${AccessKeyId}`<br>account_alias: `arn:${Partition}:iam::${Account}:alias/${AccountAlias}`<br>group: `arn:${Partition}:iam::${Account}:group/${GroupName}`<br>instance_profile: `arn:${Partition}:iam::${Account}:instance-profile/${InstanceProfileName}`<br>policy: `arn:${Partition}:iam::${Account}:policy/${PolicyName}`<br>role: `arn:${Partition}:iam::${Account}:role/${RoleName}`<br>server_certificate: `arn:${Partition}:iam::${Account}:server-certificate/${ServerCertificateName}`<br>user: `arn:${Partition}:iam::${Account}:user/${UserName}`<br>virtual_mfa_device: `arn:${Partition}:iam::${Account}:mfa/${VirtualMFADeviceName}`<br>group_policy: `arn:${Partition}:iam::${Account}:group/${GroupName}/policy/${PolicyName}`<br>role_policy: `arn:${Partition}:iam::${Account}:role/${RoleName}/policy/${PolicyName}`<br>user_policy: `arn:${Partition}:iam::${Account}:user/${UserName}/policy/${PolicyName}`<br> |
| imagebuilder | component: `arn:${Partition}:imagebuilder:${Region}:${Account}:component/${ComponentBuildVersionArn}`<br>distribution_configuration: `arn:${Partition}:imagebuilder:${Region}:${Account}:distribution-configuration/${DistributionConfigurationArn}`<br>image: `arn:${Partition}:imagebuilder:${Region}:${Account}:image/${ImageBuildVersionArn}`<br>image_pipeline: `arn:${Partition}:imagebuilder:${Region}:${Account}:image-pipeline/${ImagePipelineArn}`<br>infrastructure_configuration: `arn:${Partition}:imagebuilder:${Region}:${Account}:infrastructure-configuration/${InfrastructureConfigurationArn}`<br> |
| inspector | assessment_target: `arn:${Partition}:inspector:${Region}:${Account}:target/${AssessmentTargetArn}`<br>assessment_template: `arn:${Partition}:inspector:${Region}:${Account}:template/${AssessmentTemplateArn}`<br>assessment_run: `arn:${Partition}:inspector:${Region}:${Account}:run/${AssessmentRunArn}`<br> |
| iot | authorizer: `arn:${Partition}:iot:${Region}:${Account}:authorizer/${AuthorizerName}`<br>billing_group: `arn:${Partition}:iot:${Region}:${Account}:billinggroup/${BillingGroupName}`<br>certificate: `arn:${Partition}:iot:${Region}:${Account}:cert/${CertificateId}`<br>dimension: `arn:${Partition}:iot:${Region}:${Account}:dimension/${DimensionName}`<br>policy: `arn:${Partition}:iot:${Region}:${Account}:policy/${PolicyName}`<br>provisioning_template: `arn:${Partition}:iot:${Region}:${Account}:provisioningtemplate/${TemplateName}`<br>rule: `arn:${Partition}:iot:${Region}:${Account}:rule/${RuleName}`<br>scheduled_audit: `arn:${Partition}:iot:${Region}:${Account}:scheduledaudit/${ScheduledAuditName}`<br>thing: `arn:${Partition}:iot:${Region}:${Account}:thing/${ThingName}`<br>thing_group: `arn:${Partition}:iot:${Region}:${Account}:thinggroup/${ThingGroupName}`<br>thing_type: `arn:${Partition}:iot:${Region}:${Account}:thingtype/${ThingTypeName}`<br>topic_rule_destination: `arn:${Partition}:iot:${Region}:${Account}:topic-rule-destination/${TopicRuleDestinationName}`<br>topic_rule: `arn:${Partition}:iot:${Region}:${Account}:rule/${RuleName}`<br>domain_configuration: `arn:${Partition}:iot:${Region}:${Account}:domainconfiguration/${DomainConfigurationName}`<br>fleet_indexing_configuration: `arn:${Partition}:iot:${Region}:${Account}:fleet-indexing-configuration/${IndexingConfigurationName}`<br>job: `arn:${Partition}:iot:${Region}:${Account}:job/${JobId}`<br> |
| iot-device-tester | test_suite_run: `arn:${Partition}:iot-device-tester:${Region}:${Account}:test-suite-run:${SuiteDefinitionId}/${SuiteRunId}`<br> |
| iot1click | device: `arn:${Partition}:iot1click:${Region}:${Account}:device/${DeviceId}`<br>placement: `arn:${Partition}:iot1click:${Region}:${Account}:placement/${PlacementName}`<br>project: `arn:${Partition}:iot1click:${Region}:${Account}:project/${ProjectName}`<br> |
| iotanalytics | channel: `arn:${Partition}:iotanalytics:${Region}:${Account}:channel/${ChannelName}`<br>dataset: `arn:${Partition}:iotanalytics:${Region}:${Account}:dataset/${DatasetName}`<br>datastore: `arn:${Partition}:iotanalytics:${Region}:${Account}:datastore/${DatastoreName}`<br>pipeline: `arn:${Partition}:iotanalytics:${Region}:${Account}:pipeline/${PipelineName}`<br> |
| iotevents | input: `arn:${Partition}:iotevents:${Region}:${Account}:input/${InputName}`<br>detector_model: `arn:${Partition}:iotevents:${Region}:${Account}:detector-model/${DetectorModelName}`<br> |
| iotsitewise | asset_model: `arn:${Partition}:iotsitewise:${Region}:${Account}:asset-model/${AssetModelId}`<br>gateway: `arn:${Partition}:iotsitewise:${Region}:${Account}:gateway/${GatewayId}`<br> |
| kafka | cluster: `arn:${Partition}:kafka:${Region}:${Account}:cluster/${ClusterName}`<br> |
| kinesis | stream: `arn:${Partition}:kinesis:${Region}:${Account}:stream/${StreamName}`<br>firehose_delivery_stream: `arn:${Partition}:firehose:${Region}:${Account}:deliverystream/${DeliveryStreamName}`<br> |
| kinesis-video-archived-media | archive: `arn:${Partition}:kinesisvideo:${Region}:${Account}:archive/${StreamName}/${ArchiveId}`<br>stream: `arn:${Partition}:kinesisvideo:${Region}:${Account}:stream/${StreamName}/${StreamARN}`<br> |
| kinesis-video-media | stream: `arn:${Partition}:kinesisvideo:${Region}:${Account}:stream/${StreamName}/${StreamARN}`<br> |
| kinesis-video-signaling | channel: `arn:${Partition}:kinesisvideo:${Region}:${Account}:channel/${ChannelName}/${ChannelARN}`<br> |
| kms | key: `arn:${Partition}:kms:${Region}:${Account}:key/${KeyId}`<br>alias: `arn:${Partition}:kms:${Region}:${Account}:alias/${AliasName}`<br> |
| lakeformation | data_lake_settings: `arn:${Partition}:lakeformation:${Region}:${Account}:datalake/${DataLakeId}/settings`<br>permissions: `arn:${Partition}:lakeformation:${Region}:${Account}:permissions/${DataLakePrincipalId}/${ResourceType}/${ResourceId}`<br> |
| lambda | function: `arn:${Partition}:lambda:${Region}:${Account}:function:${FunctionName}`<br>layer: `arn:${Partition}:lambda:${Region}:${Account}:layer:${LayerName}:${LayerVersion}`<br>event_source_mapping: `arn:${Partition}:lambda:${Region}:${Account}:event-source-mapping:${UUID}`<br>event_invoke_config: `arn:${Partition}:lambda:${Region}:${Account}:event-invoke-config:${UUID}:${FunctionName}`<br> |
| lex | bot: `arn:${Partition}:lex:${Region}:${Account}:bot:${BotName}`<br>bot_alias: `arn:${Partition}:lex:${Region}:${Account}:bot:${BotName}:alias:${BotAlias}`<br>bot_channel: `arn:${Partition}:lex:${Region}:${Account}:bot-channel:${BotName}:${BotAlias}:${ChannelName}`<br> |
| license-manager | license_configuration: `arn:${Partition}:license-manager:${Region}:${Account}:license-configuration/${LicenseConfigurationId}`<br> |
| lightsail | instance: `arn:${Partition}:lightsail:${Region}:${Account}:instance/${InstanceName}`<br>key_pair: `arn:${Partition}:lightsail:${Region}:${Account}:key-pair/${KeyName}`<br>static_ip: `arn:${Partition}:lightsail:${Region}:${Account}:static-ip/${StaticIpName}`<br>load_balancer: `arn:${Partition}:lightsail:${Region}:${Account}:loadbalancer/${LoadBalancerName}`<br>bucket: `arn:${Partition}:lightsail:${Region}:${Account}:bucket/${BucketName}`<br> |
| logs | log_group: `arn:${Partition}:logs:${Region}:${Account}:log-group:${LogGroupName}`<br>log_stream: `arn:${Partition}:logs:${Region}:${Account}:log-group:${LogGroupName}:log-stream:${LogStreamName}`<br>metric_filter: `arn:${Partition}:logs:${Region}:${Account}:metric-filter:${MetricFilterName}`<br>destination: `arn:${Partition}:logs:${Region}:${Account}:destination:${DestinationName}`<br>query_definition: `arn:${Partition}:logs:${Region}:${Account}:query-definition:${QueryDefinitionName}`<br> |
| machinelearning | batch_prediction: `arn:${Partition}:machinelearning:${Region}:${Account}:batchprediction/${BatchPredictionId}`<br>data_source: `arn:${Partition}:machinelearning:${Region}:${Account}:datasource/${DataSourceId}`<br>evaluation: `arn:${Partition}:machinelearning:${Region}:${Account}:evaluation/${EvaluationId}`<br>ml_model: `arn:${Partition}:machinelearning:${Region}:${Account}:mlmodel/${MLModelId}`<br> |
| macie | classification_job: `arn:${Partition}:macie:${Region}:${Account}:classification-job/${ClassificationJobId}`<br>custom_data_identifier: `arn:${Partition}:macie:${Region}:${Account}:custom-data-identifier/${CustomDataIdentifierId}`<br>findings_filter: `arn:${Partition}:macie:${Region}:${Account}:findings-filter/${FindingsFilterId}`<br>member_account: `arn:${Partition}:macie:${Region}:${Account}:member-account/${MemberAccountId}`<br>s3_object: `arn:${Partition}:macie:${Region}:${Account}:s3-object/${S3BucketName}/${S3ObjectKey}`<br> |
| managedblockchain | network: `arn:${Partition}:managedblockchain:${Region}:${Account}:network/${NetworkId}`<br>node: `arn:${Partition}:managedblockchain:${Region}:${Account}:node/${NetworkId}/${MemberId}/${NodeId}`<br>proposal: `arn:${Partition}:managedblockchain:${Region}:${Account}:proposal/${NetworkId}/${ProposalId}`<br> |
| mediaconnect | flow: `arn:${Partition}:mediaconnect:${Region}:${Account}:flow/${FlowArn}`<br> |
| mediaconvert | queue: `arn:${Partition}:mediaconvert:${Region}:${Account}:queue/${QueueName}`<br>preset: `arn:${Partition}:mediaconvert:${Region}:${Account}:preset/${PresetName}`<br>job_template: `arn:${Partition}:mediaconvert:${Region}:${Account}:jobTemplate/${JobTemplateName}`<br> |
| medialive | channel: `arn:${Partition}:medialive:${Region}:${Account}:channel:${ChannelId}`<br> |
| mediapackage | channel: `arn:${Partition}:mediapackage:${Region}:${Account}:channel/${ChannelId}`<br>origin_endpoint: `arn:${Partition}:mediapackage:${Region}:${Account}:origin_endpoint/${OriginEndpointId}`<br> |
| mediastore | container: `arn:${Partition}:mediastore:${Region}:${Account}:container/${ContainerName}`<br> |
| mediastore-data | object: `arn:${Partition}:mediastore-data:${Region}:${Account}:object/${Path}`<br> |
| meteringmarketplace | product: `arn:${Partition}:meteringmarketplace:${Region}:${Account}:product/${ProductCode}`<br>usage_record: `arn:${Partition}:meteringmarketplace:${Region}:${Account}:usage-record:${ProductCode}/${Timestamp}/${CustomerIdentifier}`<br> |
| mgh | home_region_control: `arn:${Partition}:mgh:${Region}:${Account}:homeRegionControl/${HomeRegionControlId}`<br>migration_task: `arn:${Partition}:mgh:${Region}:${Account}:migrationTask/${MigrationTaskName}`<br>progress_update_stream: `arn:${Partition}:mgh:${Region}:${Account}:progressUpdateStream/${ProgressUpdateStreamName}`<br> |
| mobilehub | project: `arn:${Partition}:mobilehub:${Region}:${Account}:project/${ProjectId}`<br> |
| mq | broker: `arn:${Partition}:mq:${Region}:${Account}:broker:${BrokerId}`<br>configuration: `arn:${Partition}:mq:${Region}:${Account}:configuration:${ConfigurationId}`<br> |
| mturk | hit_type: `arn:${Partition}:mturk:${Region}:${Account}:hittype/${HITTypeId}`<br>hit: `arn:${Partition}:mturk:${Region}:${Account}:hit/${HITId}`<br>qualification_type: `arn:${Partition}:mturk:${Region}:${Account}:qualificationtype/${QualificationTypeId}`<br> |
| neptune-db | cluster: `arn:${Partition}:neptune-db:${Region}:${Account}:cluster:${ClusterResourceId}`<br> |
| network-firewall | firewall_policy: `arn:${Partition}:network-firewall:${Region}:${Account}:policy/${FirewallPolicyName}`<br>firewall: `arn:${Partition}:network-firewall:${Region}:${Account}:firewall/${FirewallName}`<br>rule_group: `arn:${Partition}:network-firewall:${Region}:${Account}:rulegroup/${RuleGroupName}`<br> |
| networkmanager | global_network: `arn:${Partition}:networkmanager:${Region}:${Account}:global-network/${GlobalNetworkId}`<br>device: `arn:${Partition}:networkmanager:${Region}:${Account}:device/${DeviceId}`<br>link: `arn:${Partition}:networkmanager:${Region}:${Account}:link/${LinkId}`<br>site: `arn:${Partition}:networkmanager:${Region}:${Account}:site/${SiteId}`<br> |
| opsworks | stack: `arn:${Partition}:opsworks:${Region}:${Account}:stack/${StackId}`<br>layer: `arn:${Partition}:opsworks:${Region}:${Account}:layer/${LayerId}`<br>app: `arn:${Partition}:opsworks:${Region}:${Account}:app/${AppId}`<br>instance: `arn:${Partition}:opsworks:${Region}:${Account}:instance/${InstanceId}`<br>user_profile: `arn:${Partition}:opsworks:${Region}:${Account}:user-profile/${UserProfileId}`<br>permission: `arn:${Partition}:opsworks:${Region}:${Account}:permission/${PermissionId}`<br>deployment: `arn:${Partition}:opsworks:${Region}:${Account}:deployment/${DeploymentId}`<br> |
| organizations | organization: `arn:${Partition}:organizations::${Account}:organization/${OrganizationId}`<br>account: `arn:${Partition}:organizations::${Account}:account/${AccountId}`<br>organizational_unit: `arn:${Partition}:organizations::${Account}:ou/${OrganizationalUnitId}`<br> |
| outposts | outpost: `arn:${Partition}:outposts:${Region}:${Account}:outpost/${OutpostId}`<br> |
| personalize | dataset_group: `arn:${Partition}:personalize:${Region}:${Account}:dataset-group/${DatasetGroupId}`<br>dataset: `arn:${Partition}:personalize:${Region}:${Account}:dataset/${DatasetGroupArn}/dataset/${DatasetArn}`<br>solution: `arn:${Partition}:personalize:${Region}:${Account}:solution/${SolutionArn}`<br>campaign: `arn:${Partition}:personalize:${Region}:${Account}:campaign/${CampaignArn}`<br>event_tracker: `arn:${Partition}:personalize:${Region}:${Account}:event-tracker/${EventTrackerArn}`<br> |
| pi | dimension: `arn:${Partition}:pi:${Region}:${Account}:dimension:${DimensionName}`<br> |
| pinpoint | app: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}`<br>adm_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/adm`<br>apns_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/apns`<br>apns_sandbox_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/apns_sandbox`<br>baidu_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/baidu`<br>email_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/email`<br>gcm_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/gcm`<br>sms_channel: `arn:${Partition}:mobiletargeting:${Region}:${Account}:apps/${ApplicationId}/channels/sms}`<br> |
| polly | lexicon: `arn:${Partition}:polly:${Region}:${Account}:lexicon/${LexiconName}`<br> |
| qldb | ledger: `arn:${Partition}:qldb:${Region}:${Account}:ledger/${LedgerName}`<br> |
| quickSight | group: `arn:${Partition}:quicksight:${Region}:${Account}:group/${GroupName}`<br>user: `arn:${Partition}:quicksight:${Region}:${Account}:user/${UserName}`<br> |
| ram | resource_share: `arn:${Partition}:ram:${Region}:${Account}:resource-share/${ResourceShareName}`<br>resource_share_invitation: `arn:${Partition}:ram:${Region}:${Account}:resource-share-invitation/${ResourceShareInvitationId}`<br> |
| rds | db_instance: `arn:${Partition}:rds:${Region}:${Account}:db:${DBInstanceIdentifier}`<br>db_snapshot: `arn:${Partition}:rds:${Region}:${Account}:snapshot:${DBSnapshotIdentifier}`<br>db_cluster: `arn:${Partition}:rds:${Region}:${Account}:cluster:${DBClusterIdentifier}`<br>db_cluster_snapshot: `arn:${Partition}:rds:${Region}:${Account}:cluster-snapshot:${DBClusterSnapshotIdentifier}`<br>option_group: `arn:${Partition}:rds:${Region}:${Account}:og:${OptionGroupName}`<br>parameter_group: `arn:${Partition}:rds:${Region}:${Account}:pg:${DBParameterGroupName}`<br>subgroup: `arn:${Partition}:rds:${Region}:${Account}:sub-group:${DBSubnetGroupName}`<br>event_subscription: `arn:${Partition}:rds:${Region}:${Account}:es:${EventSubscriptionName}`<br>global_cluster: `arn:${Partition}:rds:${Region}:${Account}:global-cluster:${GlobalClusterIdentifier}`<br> |
| rds-data | secret: `arn:${Partition}:secretsmanager:${Region}:${Account}:secret:${SecretId}`<br> |
| redshift | cluster: `arn:${Partition}:redshift:${Region}:${Account}:cluster:${ClusterName}`<br>snapshot: `arn:${Partition}:redshift:${Region}:${Account}:snapshot:${SnapshotName}`<br> |
| rekognition | collection: `arn:${Partition}:rekognition:${Region}:${Account}:collection/${CollectionId}`<br>stream_processor: `arn:${Partition}:rekognition:${Region}:${Account}:stream-processor/${StreamProcessorName}`<br> |
| resource-groups | group: `arn:${Partition}:resource-groups:${Region}:${Account}:group/${GroupName}`<br> |
| robomaker | robot_application: `arn:${Partition}:robomaker:${Region}:${Account}:robot-application/${ApplicationName}/${ApplicationVersion}`<br>simulation_application: `arn:${Partition}:robomaker:${Region}:${Account}:simulation-application/${ApplicationName}/${ApplicationVersion}`<br>robot: `arn:${Partition}:robomaker:${Region}:${Account}:robot/${RobotName}`<br>simulation_job: `arn:${Partition}:robomaker:${Region}:${Account}:simulation-job/${SimulationJobArn}`<br>fleet: `arn:${Partition}:robomaker:${Region}:${Account}:fleet/${FleetName}`<br> |
| route53 | health_check: `arn:${Partition}:route53:::healthcheck/${HealthCheckId}`<br>hosted_zone: `arn:${Partition}:route53:::hostedzone/${HostedZoneId}`<br>vpc_association_authorization: `arn:${Partition}:route53:::vpc/${VPCRegion}:${VPCId}:authorizevpcassociation/${HostedZoneId}/${VPCId}`<br>resolver_endpoint: `arn:${Partition}:route53resolver:${Region}:${Account}:resolver-endpoint/${ResolverEndpointId}`<br>resolver_rule: `arn:${Partition}:route53resolver:${Region}:${Account}:resolver-rule/${ResolverRuleId}`<br>resolver_rule_association: `arn:${Partition}:route53resolver:${Region}:${Account}:resolver-rule-association/${ResolverRuleAssociationId}`<br> |
| s3 | bucket: `arn:${Partition}:s3:::${BucketName}`<br>object: `arn:${Partition}:s3:::${BucketName}/${ObjectName}`<br> |
| s3-object-lambda | access_point: `arn:${Partition}:s3-object-lambda:${Region}:${Account}:accesspoint/${AccessPointName}`<br>access_point_policy: `arn:${Partition}:s3-object-lambda:${Region}:${Account}:accesspoint-policy/${AccessPointName}`<br>access_point_configuration: `arn:${Partition}:s3-object-lambda:${Region}:${Account}:accesspoint/${AccessPointName}/configuration`<br> |
| sagemaker | notebook_instance: `arn:${Partition}:sagemaker:${Region}:${Account}:notebook-instance/${NotebookInstanceName}`<br>notebook_instance_lifecycle_configuration: `arn:${Partition}:sagemaker:${Region}:${Account}:notebook-instance-lifecycle-config/${NotebookInstanceLifecycleConfigName}`<br>training_job: `arn:${Partition}:sagemaker:${Region}:${Account}:training-job/${TrainingJobName}`<br>processing_job: `arn:${Partition}:sagemaker:${Region}:${Account}:processing-job/${ProcessingJobName}`<br>transform_job: `arn:${Partition}:sagemaker:${Region}:${Account}:transform-job/${TransformJobName}`<br>model: `arn:${Partition}:sagemaker:${Region}:${Account}:model/${ModelName}`<br>endpoint_config: `arn:${Partition}:sagemaker:${Region}:${Account}:endpoint-config/${EndpointConfigName}`<br>endpoint: `arn:${Partition}:sagemaker:${Region}:${Account}:endpoint/${EndpointName}`<br>feature_group: `arn:${Partition}:sagemaker:${Region}:${Account}:feature-group/${FeatureGroupName}`<br> |
| sdb | domain: `arn:${Partition}:sdb:${Region}:${Account}:domain/${DomainName}`<br> |
| secretsmanager | secret: `arn:${Partition}:secretsmanager:${Region}:${Account}:secret:${SecretId}`<br> |
| securityhub | hub: `arn:${Partition}:securityhub:${Region}:${Account}:hub/default`<br>product_subscription: `arn:${Partition}:securityhub:${Region}:${Account}:subscription/${SubscriptionId}`<br> |
| serverlessrepo | application: `arn:${Partition}:serverlessrepo:${Region}:${Account}:applications/${ApplicationId}/${SemanticVersion}`<br> |
| servicecatalog | product: `arn:${Partition}:catalog:${Region}:${Account}:product/${ProductId}`<br>portfolio: `arn:${Partition}:catalog:${Region}:${Account}:portfolio/${PortfolioId}`<br>portfolio_share: `arn:${Partition}:catalog:${Region}:${Account}:share/${ShareId}`<br>cloudformation_stack_set_constraint: `arn:${Partition}:cloudformation:${Region}:${Account}:stack-set/${StackSetName}:constraint/${ConstraintId}`<br> |
| servicediscovery | namespace: `arn:${Partition}:servicediscovery:${Region}:${Account}:namespace/${NamespaceId}`<br>service: `arn:${Partition}:servicediscovery:${Region}:${Account}:service/${ServiceId}`<br> |
| ses | configuration_set: `arn:${Partition}:ses:${Region}:${Account}:configuration-set/${ConfigurationSetName}`<br> |
| shield | protection: `arn:${Partition}:shield::${Account}:protection/${ProtectionId}`<br> |
| signer | signing_profile: `arn:${Partition}:signer:${Region}:${Account}:signing-profiles/${SigningProfileName}`<br> |
| sms | app: `arn:${Partition}:sms:${Region}:${Account}:app/${AppId}`<br>server: `arn:${Partition}:sms:${Region}:${Account}:server/${ServerId}`<br>replication_job: `arn:${Partition}:sms:${Region}:${Account}:replication-job/${ReplicationJobId}`<br> |
| snowball | job: `arn:${Partition}:snowball:${Region}:${Account}:job/${JobId}`<br> |
| sns | topic: `arn:${Partition}:sns:${Region}:${Account}:${TopicName}`<br>subscription: `arn:${Partition}:sns:${Region}:${Account}:${TopicName}:${SubscriptionId}`<br>platform_application_endpoint: `arn:${Partition}:sns:${Region}:${Account}:app/${PlatformApplicationArn}/${EndpointId}`<br> |
| sqs | queue: `arn:${Partition}:sqs:${Region}:${Account}:${QueueName}`<br> |
| ssm | document: `arn:${Partition}:ssm:${Region}:${Account}:document/${DocumentName}`<br>parameter: `arn:${Partition}:ssm:${Region}:${Account}:parameter/${ParameterName}`<br>maintenance_window: `arn:${Partition}:ssm:${Region}:${Account}:maintenancewindow/${WindowId}`<br>maintenance_window_task: `arn:${Partition}:ssm:${Region}:${Account}:maintenancewindow/${WindowId}/task/${WindowTaskId}`<br>patch_baseline: `arn:${Partition}:ssm:${Region}:${Account}:patchbaseline/${BaselineId}`<br> |
| sso | instance: `arn:${Partition}:sso:${Region}:${Account}:instance/${InstanceId}`<br>permission_set: `arn:${Partition}:sso:${Region}:${Account}:permissionSet/${PermissionSetId}`<br> |
| sso-directory | directory: `arn:${Partition}:sso-directory:${Region}:${Account}:directory/${DirectoryId}`<br> |
| stepfunctions | state_machine: `arn:${Partition}:states:${Region}:${Account}:stateMachine:${StateMachineName}`<br> |
| storagegateway | gateway: `arn:${Partition}:storagegateway:${Region}:${Account}:gateway/${GatewayId}`<br>share: `arn:${Partition}:storagegateway:${Region}:${Account}:share/${ShareId}`<br>tape: `arn:${Partition}:storagegateway:${Region}:${Account}:tape/${TapeARN}`<br>volume: `arn:${Partition}:storagegateway:${Region}:${Account}:gateway/${GatewayId}/volume/${VolumeId}`<br> |
| sts | assumed_role: `arn:${Partition}:sts::${Account}:assumed-role/${RoleName}/${RoleSessionName}`<br>federated_user: `arn:${Partition}:sts::${Account}:federated-user/${UserName}`<br>oidc_provider: `arn:${Partition}:iam::${Account}:oidc-provider/${Url}`<br>saml_provider: `arn:${Partition}:iam::${Account}:saml-provider/${Name}`<br>user: `arn:${Partition}:iam::${Account}:user/${UserName}`<br> |
| swf | domain: `arn:${Partition}:swf:${Region}:${Account}:domain/${DomainName}`<br>workflow_type: `arn:${Partition}:swf:${Region}:${Account}:workflowType/${DomainName}/${WorkflowTypeName}`<br>activity_type: `arn:${Partition}:swf:${Region}:${Account}:activityType/${DomainName}/${ActivityTypeName}`<br>workflow_execution: `arn:${Partition}:swf:${Region}:${Account}:workflow/${DomainName}/${WorkflowExecutionType}:${WorkflowExecutionId}`<br>activity_execution: `arn:${Partition}:swf:${Region}:${Account}:activity/${DomainName}/${ActivityTypeName}:${ActivityId}`<br> |
| synthetics | canary: `arn:${Partition}:synthetics:${Region}:${Account}:canary:${CanaryName}`<br>canary_run: `arn:${Partition}:synthetics:${Region}:${Account}:canary:${CanaryName}:run:${CanaryRunId}`<br> |
| textract | document: `arn:${Partition}:textract:${Region}:${Account}:document/${DocumentId}`<br> |
| transcribe | vocabulary: `arn:${Partition}:transcribe:${Region}:${Account}:vocabulary/${VocabularyName}`<br> |
| transfer | server: `arn:${Partition}:transfer:${Region}:${Account}:server/${ServerId}`<br>user: `arn:${Partition}:transfer:${Region}:${Account}:user/${ServerId}/${UserName}`<br>role: `arn:${Partition}:iam::${Account}:role/service-role/${RoleName}`<br> |
| translate | terminology: `arn:${Partition}:translate:${Region}:${Account}:terminology/${TerminologyName}`<br> |
| waf | ipset: `arn:${Partition}:waf:${Region}:${Account}:ipset/${IpSetId}`<br>rule: `arn:${Partition}:waf:${Region}:${Account}:rule/${RuleId}`<br>web_acl: `arn:${Partition}:waf:${Region}:${Account}:webacl/${WebACLId}`<br>regional_rule_group: `arn:${Partition}:waf::${Account}:regional-rulegroup/${RuleGroupName}/${RuleGroupId}`<br>regional_web_acl: `arn:${Partition}:waf::${Account}:webacl/${WebACLName}/${WebACLId}`<br>global_web_acl: `arn:${Partition}:waf::${Account}:global-webacl/${WebACLName}/${WebACLId}`<br> |
| waf-regional | ipset: `arn:${Partition}:waf-regional:${Region}:${Account}:ipset/${IpSetId}`<br>rule: `arn:${Partition}:waf-regional:${Region}:${Account}:rule/${RuleId}`<br>web_acl: `arn:${Partition}:waf-regional:${Region}:${Account}:webacl/${WebACLId}`<br>regional_rule_group: `arn:${Partition}:waf-regional:${Region}:${Account}:rulegroup/${RuleGroupName}/${RuleGroupId}`<br>regional_web_acl: `arn:${Partition}:waf-regional:${Region}:${Account}:webacl/${WebACLName}/${WebACLId}`<br> |
| wafv2 | ip_set: `arn:${Partition}:wafv2:${Region}:${Account}:/ipset/${Scope}/${Id}`<br>rule_group: `arn:${Partition}:wafv2:${Region}:${Account}:/rulegroup/${Scope}/${Id}`<br>web_acl: `arn:${Partition}:wafv2:${Region}:${Account}:/webacl/${Scope}/${Id}`<br> |
| wellarchitected | workload: `arn:${Partition}:wellarchitected:${Region}:${Account}:workload/${WorkloadId}`<br> |
| workdocs | document: `arn:${Partition}:workdocs:${Region}:${Account}:${FolderHierarchy}/${DocumentName}`<br>folder: `arn:${Partition}:workdocs:${Region}:${Account}:${FolderHierarchy}/${FolderName}`<br>user: `arn:${Partition}:workdocs:${Region}:${Account}:user/${UserId}`<br> |
| worklink | fleet: `arn:${Partition}:worklink:${Region}:${Account}:fleet/${FleetArnName}`<br>website_certificate_authority_association: `arn:${Partition}:worklink:${Region}:${Account}:website-certificate-authority-association/${WebsiteCertificateAuthorityAssociationId}`<br> |
| workmail | organization: `arn:${Partition}:workmail:${Region}:${Account}:organization/${OrganizationId}`<br>resource: `arn:${Partition}:workmail:${Region}:${Account}:resource/${ResourceId}`<br>user: `arn:${Partition}:workmail:${Region}:${Account}:user/${UserId}`<br> |
| workspaces | directory: `arn:${Partition}:workspaces:${Region}:${Account}:directory/${DirectoryId}`<br>workspace: `arn:${Partition}:workspaces:${Region}:${Account}:workspace/${WorkspaceId}`<br> |